/* Micro Java: Exception for invalid class files (mah 99-5-10)
   =============================================
*/
package MJ.VM;

import java.io.*;

// implementation of VM in/out for console usage
class CommandIO implements inOutVM {
  InputStream in;
  OutputStream out;

  CommandIO (InputStream i, OutputStream o) {
    in = i; out = o;
  }

  public void print (byte b) throws IOException {
    out.write(b);
  }

  public byte read () throws IOException {
    return (byte)in.read();
  }

  public void stopped (boolean state) {
    if (state) System.out.println("VM aborted with an error!");
    else System.out.println();
  }
}

public class Interpreter {

  public static void main (String args[]) {
    int idx = 0;
    boolean ui, debug, err = false;
    String name;
    VM vm = new VM(new CommandIO(System.in, System.out));

    ui = args.length==0;  // no args => grahical UI
    for(int i=0; i<args.length && args[i].charAt(0)=='-'; i++) {
      ui = ui || args[i].equalsIgnoreCase("-UI");
      vm.debug = vm.debug || args[i].equalsIgnoreCase("-DEBUG");
    }
    if (ui) idx++;
    if (vm.debug) idx++;
    if (idx>=args.length) name = "";
    else name = args[idx];

    try {
      vm.load(name);
    } catch (IOException ex) {
      err = true;
      if (!ui) System.out.println("File '"+args[idx]+"' not found.");
    } catch (FormatException ex) {
      err = true;
      if (!ui) {
        System.out.println("File '"+args[idx]+"' is not a valid MicroJava class file.");
        System.out.println("Explanation: "+ex.getMessage());
      }
    }
    if (ui) new UI(vm, name);   // start UI
    else if (!err) vm.interpret();  // run program on console
  }
}
